summaryrefslogtreecommitdiffstats
path: root/ash/ash_switches.cc
diff options
context:
space:
mode:
authormfomitchev@chromium.org <mfomitchev@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-13 21:43:49 +0000
committermfomitchev@chromium.org <mfomitchev@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-13 21:43:49 +0000
commit5ed2f818e52dca5319c37859004ed17a7c3caed2 (patch)
treefae54bc7758243ffe051576dc77a757cd722ce66 /ash/ash_switches.cc
parent72af5c558d6d5b28285f95a9d5a38c76a8ba73d6 (diff)
downloadchromium_src-5ed2f818e52dca5319c37859004ed17a7c3caed2.zip
chromium_src-5ed2f818e52dca5319c37859004ed17a7c3caed2.tar.gz
chromium_src-5ed2f818e52dca5319c37859004ed17a7c3caed2.tar.bz2
Implementation of the Touch Exploration Mode - Part III (enabled by default)
This CL makes Touch Exploration Mode enabled by default. This is dependent on Part I and II: https://codereview.chromium.org/262483003 https://codereview.chromium.org/261863002 BUG=368828 Review URL: https://codereview.chromium.org/266923003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@270216 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/ash_switches.cc')
-rw-r--r--ash/ash_switches.cc9
1 files changed, 5 insertions, 4 deletions
diff --git a/ash/ash_switches.cc b/ash/ash_switches.cc
index acc29b1..327e7ea 100644
--- a/ash/ash_switches.cc
+++ b/ash/ash_switches.cc
@@ -41,10 +41,11 @@ const char kAshDefaultWallpaperSmall[] = "ash-default-wallpaper-small";
// Disable ability to dock windows at the desktop edge.
const char kAshDisableDockedWindows[] = "ash-disable-docked-windows";
-// Enable the Touch Exploration Mode. Touch Exploration Mode will be turned on
-// automatically when spoken feedback is enabled when this flag is set.
-const char kAshEnableTouchExplorationMode[] =
- "ash-enable-touch-exploration-mode";
+// Disable the Touch Exploration Mode. Touch Exploration Mode will no longer be
+// turned on automatically when spoken feedback is enabled when this flag is
+// set.
+const char kAshDisableTouchExplorationMode[] =
+ "ash-disable-touch-exploration-mode";
#if defined(OS_CHROMEOS)
// Enables key bindings to scroll magnified screen.